# The hardening flags cause gawk to core dump on the pma test
%undefine _hardened_build

Summary:	The GNU version of the awk text processing utility
Name:		gawk
Version:	5.3.0
Release:	%mkrel 4
License:	GPLv3+
Group:		Text tools
URL:		https://www.gnu.org/software/gawk/gawk.html
Source0:	https://ftp.gnu.org/gnu/gawk/%{name}-%{version}.tar.xz
Source1:	https://ftp.gnu.org/gnu/gawk/%{name}-3.1.6-ps.tar.gz

# Upstream stable branch fixes
# https://git.savannah.gnu.org/cgit/gawk.git/log/?h=gawk-5.2-stable

Provides:	awk
BuildRequires:	byacc
BuildRequires:	gettext-devel
BuildRequires:	libsigsegv-devel >= 2.8
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	libtool
BuildRequires:	texinfo
# Extending GAWK possibilities:
BuildRequires:    libsigsegv-devel
BuildRequires:    mpfr-devel
BuildRequires:    readline-devel
# This allows some locale specific tests to pass
BuildRequires:	locales-en
Requires(pre):	filesystem >= 2.1.9-18
Conflicts:      mkbootdisk < 1.5.4

%description
The gawk packages contains the GNU version of awk, a text processing
utility.  Awk interprets a special-purpose programming language to do
quick and easy text pattern matching and reformatting jobs. Gawk should
be upwardly compatible with the Bell Labs research version of awk and
is almost completely compliant with the 1993 POSIX 1003.2 standard for
awk.

Install the gawk package if you need a text processing utility. Gawk is
considered to be a standard Linux tool for processing text.

%package	doc
Summary:	Documentation about the GNU version of the awk text processing utility
Group:		Documentation

%description	doc
The gawk packages contains the GNU version of awk, a text processing
utility.  Awk interprets a special-purpose programming language to do
quick and easy text pattern matching and reformatting jobs. Gawk should
be upwardly compatible with the Bell Labs research version of awk and
is almost completely compliant with the 1993 POSIX 1003.2 standard for
awk.

%prep
%autosetup -p1 -b 1

# This disables a test ("time.awk" / "time.ok" ) that sometimes fails on the
# build system
echo 'BEGIN { printf "%%d\n", 1; }' > test/time.awk
echo '1' > test/time.ok

mv ../%{name}-3.1.6/doc/*.ps doc
rm -rf ../%{name}-3.1.6

%build
%configure
%make_build

%check
make check

%install
%make_install

%find_lang %{name}

ln -s gawk.1 %{buildroot}%{_mandir}/man1/awk.1
rm %{buildroot}%{_bindir}/gawk-%{version}

%files -f %{name}.lang
%{_bindir}/*
%{_mandir}/*/*
%{_infodir}/*
%{_libexecdir}/awk
%{_datadir}/awk
%{_libdir}/gawk
%{_includedir}/gawkapi.h
%{_sysconfdir}/profile.d/*

%files doc
%doc README INSTALL NEWS
%doc README_d POSIX.STD doc/*.ps


%changelog
* Sat May 11 2024 danf <danf> 5.3.0-4.mga10
+ Revision: 2063358
- Disable hardened_build which causes core dump during tests

* Fri Apr 05 2024 wally <wally> 5.3.0-3.mga10
+ Revision: 2054854
- another rebuild due to a BS hickup

* Fri Apr 05 2024 wally <wally> 5.3.0-2.mga10
+ Revision: 2054613
- basesystem rebuild for i686

* Thu Nov 02 2023 kekepower <kekepower> 5.3.0-1.mga10
+ Revision: 2003668
- Update to version 5.3.0

* Tue May 09 2023 kekepower <kekepower> 5.2.2-1.mga9
+ Revision: 1956305
- Update to version 5.2.2

* Tue Nov 22 2022 kekepower <kekepower> 5.2.1-1.mga9
+ Revision: 1910314
- Update to version 5.2.1

* Wed Oct 12 2022 tmb <tmb> 5.2.0-4.mga9
+ Revision: 1896629
- add BR: texinfo
- add more fixes from upstream gawk-5.2-stable branch

* Wed Sep 14 2022 pterjan <pterjan> 5.2.0-3.mga9
+ Revision: 1888638
- Add a patch for the crash reported in mga#30825

* Mon Sep 05 2022 kekepower <kekepower> 5.2.0-2.mga9
+ Revision: 1884257
- Add upstream patch to fix "free(): double free detected in tcache 2"

* Mon Sep 05 2022 kekepower <kekepower> 5.2.0-1.mga9
+ Revision: 1883988
- Update to version 5.2.0

* Fri Mar 18 2022 umeabot <umeabot> 5.1.1-2.mga9
+ Revision: 1798776
- Mageia 9 Mass Rebuild

* Fri Oct 29 2021 kekepower <kekepower> 5.1.1-1.mga9
+ Revision: 1753247
- Update to version 5.1.1

* Fri Apr 24 2020 shlomif <shlomif> 5.1.0-1.mga8
+ Revision: 1571678
- New version 5.1.0

* Thu Apr 16 2020 tv <tv> 5.0.1-5.mga8
+ Revision: 1567762
- extend gawk possibilities with mpfr/readline/...

* Thu Apr 16 2020 tv <tv> 5.0.1-4.mga8
+ Revision: 1567752
- remove info-install dep

* Sat Feb 15 2020 umeabot <umeabot> 5.0.1-3.mga8
+ Revision: 1527977
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Jul 29 2019 shlomif <shlomif> 5.0.1-2.mga8
+ Revision: 1424855
- Rebuild for core

* Fri Jul 12 2019 shlomif <shlomif> 5.0.1-1.mga8
+ Revision: 1420809
- New version 5.0.1

* Mon Sep 03 2018 tv <tv> 4.2.1-2.mga7
+ Revision: 1256401
- rely on filetriggers for info system (mga#23482)

* Mon Feb 26 2018 wally <wally> 4.2.1-1.mga7
+ Revision: 1205261
- new version 4.2.1

* Fri Oct 27 2017 joequant <joequant> 4.2.0-1.mga7
+ Revision: 1173975
- upgrade to 4.2.0

* Thu Sep 07 2017 joequant <joequant> 4.1.4-2.mga7
+ Revision: 1151743
- upgrade with new gcc/binutils

* Fri Aug 26 2016 luigiwalser <luigiwalser> 4.1.4-1.mga6
+ Revision: 1049077
- 4.1.4

* Thu Feb 11 2016 umeabot <umeabot> 4.1.3-3.mga6
+ Revision: 953973
- Mageia 6 Mass Rebuild

* Fri Aug 21 2015 tmb <tmb> 4.1.3-2.mga6
+ Revision: 867455
- rebuild for new gcc

* Sat Jul 25 2015 blino <blino> 4.1.3-1.mga6
+ Revision: 857147
- 4.1.3
- drop merged patches

* Sat Mar 07 2015 shlomif <shlomif> 4.1.1-4.mga5
+ Revision: 817999
- Disable a test that sometimes fails on the BS due to timings.

* Wed Oct 15 2014 umeabot <umeabot> 4.1.1-3.mga5
+ Revision: 740740
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 4.1.1-2.mga5
+ Revision: 679424
- Mageia 5 Mass Rebuild

* Sun Aug 31 2014 pterjan <pterjan> 4.1.1-1.mga5
+ Revision: 669846
- BuildRequires locales-en to fix tests
+ luigiwalser <luigiwalser>
- 4.1.1
- add patch to fix rm outside of buildroot in make install
- add patch from fedora to fix invalid free bug (rhbz#1089073)

* Sat Oct 19 2013 umeabot <umeabot> 4.1.0-2.mga4
+ Revision: 525737
- Mageia 4 Mass Rebuild

* Sun Jun 02 2013 luigiwalser <luigiwalser> 4.1.0-1.mga4
+ Revision: 434321
- 4.1.0
- clean up install procedure
- add new files for C extension mechanism added in gawk 4.1.0

* Sat May 04 2013 anssi <anssi> 4.0.2-4.mga3
+ Revision: 412280
- add conflicts against old mkbootdisk for smooth upgrade

* Fri Jan 11 2013 umeabot <umeabot> 4.0.2-3.mga3
+ Revision: 351081
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 02 2013 pterjan <pterjan> 4.0.2-2.mga3
+ Revision: 337528
- Fix for _libdir != _libexecdir

* Wed Dec 26 2012 luigiwalser <luigiwalser> 4.0.2-1.mga3
+ Revision: 335540
- 4.0.2

* Wed Oct 10 2012 shlomif <shlomif> 4.0.1-4.mga3
+ Revision: 304282
- Bump release to please the build system
- Convert the doc package group to Documentation (per revamp)

* Sat Jul 21 2012 colin <colin> 4.0.1-2.mga3
+ Revision: 273158
- Update for usrmove

* Sun Apr 15 2012 luigiwalser <luigiwalser> 4.0.1-1.mga2
+ Revision: 230947
- 4.0.1

* Sat Sep 03 2011 guillomovitch <guillomovitch> 4.0.0-1.mga2
+ Revision: 138253
- spec cleanup
+ fwang <fwang>
- new version 4.0.0

* Sun Jan 09 2011 blino <blino> 3.1.8-1.mga1
+ Revision: 3670
- imported package gawk

